Class: EasyCaddy::Commands::Audit::Choice

Inherits:
Data
  • Object
show all
Defined in:
lib/easy_caddy/commands/audit.rb

Overview

A single labelled option offered when a Fix has multiple remedies (e.g. a root-owned log the user may want to keep, take ownership of, or delete). command: nil means “do nothing”.

Instance Attribute Summary collapse

Instance Attribute Details

#commandObject (readonly)

Returns the value of attribute command

Returns:

  • (Object)

    the current value of command



35
36
37
# File 'lib/easy_caddy/commands/audit.rb', line 35

def command
  @command
end

#labelObject (readonly)

Returns the value of attribute label

Returns:

  • (Object)

    the current value of label



35
36
37
# File 'lib/easy_caddy/commands/audit.rb', line 35

def label
  @label
end

#verifyObject (readonly)

Returns the value of attribute verify

Returns:

  • (Object)

    the current value of verify



35
36
37
# File 'lib/easy_caddy/commands/audit.rb', line 35

def verify
  @verify
end