Class: EasyCaddy::Commands::Audit::Choice
- Inherits:
-
Data
- Object
- Data
- EasyCaddy::Commands::Audit::Choice
- Defined in:
- lib/easy_caddy/commands/audit.rb
Overview
A single labelled option offered when a Fix has multiple remedies (e.g. a root-owned log the user may want to keep, take ownership of, or delete). command: nil means “do nothing”.
Instance Attribute Summary collapse
-
#command ⇒ Object
readonly
Returns the value of attribute command.
-
#label ⇒ Object
readonly
Returns the value of attribute label.
-
#verify ⇒ Object
readonly
Returns the value of attribute verify.
Instance Attribute Details
#command ⇒ Object (readonly)
Returns the value of attribute command
35 36 37 |
# File 'lib/easy_caddy/commands/audit.rb', line 35 def command @command end |
#label ⇒ Object (readonly)
Returns the value of attribute label
35 36 37 |
# File 'lib/easy_caddy/commands/audit.rb', line 35 def label @label end |
#verify ⇒ Object (readonly)
Returns the value of attribute verify
35 36 37 |
# File 'lib/easy_caddy/commands/audit.rb', line 35 def verify @verify end |